# PySnobal

[![PyPI version](https://badge.fury.io/py/pysnobal.svg)](https://badge.fury.io/py/pysnobal)

[![Build Status](https://travis-ci.com/scotthavens/pysnobal.svg?branch=master)](https://travis-ci.com/scotthavens/pysnobal)

[![Coverage Status](https://coveralls.io/repos/github/scotthavens/pysnobal/badge.svg?branch=master)](https://coveralls.io/github/scotthavens/pysnobal?branch=master)

Python implemenation of the Snobal model at a point or over a grid. This package has converted all the original C code to Python.

## Todo

Lots
